@@ -1,6 +1,6 @@
 #!/bin/bash
 
-mversion=3.0
+mversion=3.1
 TTSENGINE=loquendo
 
 echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
@@ -24,8 +24,12 @@ fi
 
 #Check Loquendo Version
 if [ -d /opt/Loquendo/LTTS7 ];then
-  lttsver=7
   ltts=/opt/Loquendo/LTTS7
+  if [ -f $ltts/bin/ssml2wav ];then
+    lttsver=71
+  else
+    lttsver=7
+  fi
 elif [ -d /opt/LTTS  ];then
   lttsver=6
   ltts=/opt/LTTS
@@ -48,17 +52,26 @@ echo "Selected www dir : $wwwdirselect"
 mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE
 install -m $perm_files $src/www/* $dst/$wwwdirselect/tts/$TTSENGINE
 mv -v $dst/$wwwdirselect/tts/$TTSENGINE/config${lttsver}.php $dst/$wwwdirselect/tts/$TTSENGINE/config.php
-rm -rvf $dst/$wwwdirselect/tts/$TTSENGINE/config?.php
+rm -rf $dst/$wwwdirselect/tts/$TTSENGINE/config?.php
 
-[ -f $ltts/bin/TTSFileGenerator ] && mv $ltts/bin/TTSFileGenerator $ltts/bin/TTSFileGenerator.old
+if [ ! $lttsver = "71" ];then
+  #Save old binary for version 6 or 7
+  if [ -f $ltts/bin/TTSFileGenerator ] && [ ! -f $ltts/bin/TTSFileGenerator.orig ];then
+    mv $ltts/bin/TTSFileGenerator $ltts/bin/TTSFileGenerator.orig
+  elif [ -f $ltts/bin/TTSFileGenerator.orig ]; then
+    mv $ltts/bin/TTSFileGenerator $ltts/bin/TTSFileGenerator.bck.$(date +%Y-%m-%d)
+  fi
 
-ARCH=`uname -m`
-if [ "$ARCH" = "x86_64" ] ; then  
-	echo "Installing x86_64  binaries..."
-	install -m $perm_exec $src/bin/TTSFileGenerator${lttsver}_64 $ltts/bin/TTSFileGenerator
+  ARCH=`uname -m`
+  if [ "$ARCH" = "x86_64" ] ; then  
+    echo "Installing x86_64  binaries..."
+    install -m $perm_exec $src/bin/TTSFileGenerator${lttsver}_64 $ltts/bin/TTSFileGenerator
+  else
+    echo "Installing i386 binaries..."
+    install -m $perm_exec $src/bin/TTSFileGenerator${lttsver} $ltts/bin/TTSFileGenerator
+  fi
 else
-	echo "Installing i386 binaries..."
-	install -m $perm_exec $src/bin/TTSFileGenerator${lttsver} $ltts/bin/TTSFileGenerator
+  echo "Echo Version 7.1 do not need binaries... uses ssml2wav"
 fi
 
 echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"
